/*

DESCRIPTION:
    Main include file for ms5607_dev.c.

COPYRIGHT:      (c) 2021, Brian Cornell, all rights reserved.

 TARGET MCU:    PIC16LF18326

HW REVISION:    n/a

HW RELEASE:     210120

VERSION:        2.0

MODIFICATION HISTORY:

    17 Jan 21, BWC, version 2.0

    3 Jan 21, BWC, version 1.1

    27 Dec 20, BWC, first production release (1.0)

    21 Dec 20, BWC, adapted for hardware release 201218.

    3 Dec 20, BWC, created project adapted I2C version.


*/



/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Version constants & definitions.  Build number is defined in constant 
 * VERBUILD and maintained by shell script build.sh and included in build.h.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define VERMAJOR    2
#define VERMINOR    0


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Necessary includes.  Build.h contains the build number constant which is
 * maintained by the makefile.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#ifndef UINT_MAX
#include <limits.h>
#endif
#include "build.h"


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Conditional compilation.  Uncomment directive to enable / disable features.
 * + HWR210120: uncomment to compile for hardware release (HWR) 210120; 
 *   otherwise compiled for breadboard pin-out.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define HWR210120


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                  Configure system clock & Watchdog Timer
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_OSC_NOSC    0x6             //HFINTOSC (1 MHz)
#define CFG_OSC_NDIV    0x0             //Clock divider by 1
#define CFG_OSC_HFFRQ   0x6             //HFINTOSC freququency 16MHz
#define CFG_OSC_OSCTUNE 0x00            //HFINTOSC adjustment

#define CFG_WDT_CON     0x18            //Watchdog interval=4s, off.


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * System wide constants & definitions.  Convention:  S_<TYPE>_<INFO>
 * Types:
 *  + DC=Duty Cycle
 *  + DF=Default value for a configurable parameter
 *  + EN=ENable bit
 *  + RT=RaTio or scaling factor
 *  + LM=LiMiting operational value
 *  + TM=TiMing
 *  + MP=Peripheral port bit MaPping
 *  + CH=character
 *  + IN=INitializing value
 *  + VL=VoLtage
 *  + QY=quantity (count) of something
 *  + CD=command data
 *  + BL=boolean value
 *  + MK=bit MasK
 *  + SZ=size of an object or data type
 * 
 * Info is user defined and should be descriptive.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define S_TM_TMR6           10              //Timer6 period in mS
#define S_QY_MS_S           1000            //Number of mS in one second
#define S_QY_TMR6_1S        (S_QY_MS_S / S_TM_TMR6) //# of timer6 periods=1S
#define S_LM_VDD_NVM        3               //Vdd > to allow NVM writes
#define S_SZ_BYTE           8               //Number of bits in a byte
#define S_MK_U16_L          0x00FF          //Mask to access low byte of 16-bit unsigned
#define S_MK_U16_H          0xFF00          //Mask to access high byte of 16-bit unsigned
#define S_TM_INT_CHGP       100             //# mS for charge pump startup
#define S_TM_INT_LCDB       100             //# mS for LCD/Baro to boot
#define S_TM_CRC_RB         1000            //# mS to pause before reboot d/t CRC
#define S_CH_SPACE          ' '             //White space
#define S_CH_COMMA          ','             //Comma
#define S_CH_ZERO           '0'             //Number zero
#define S_CH_CAP_M          'M'             //Capital letter M
#define S_CH_DECIMAL        '.'             //Decimal point
#define S_AR_UINT16_L       0               //uint16_t byte mapping
#define S_AR_UINT16_H       1               //uint16_t byte mapping
#define S_AR_UINT16_LL_L    0               //uint16_t mapped to long long
#define S_AR_UINT16_LL_H    1               //uint16_t mapped to long long
#define S_AR_LONG_1         0               //Long int byte mapping
#define S_AR_LONG_2         1               //Long int byte mapping
#define S_AR_LONG_3         2               //Long int byte mapping
#define S_AR_LONG_4         3               //Long int byte mapping
#define S_AR_LONG_LL_1      0               //Long int mapped to long long
#define S_AR_LONG_LL_2      1               //Long int mapped to long long
#define S_AR_LONG_LL_3      2               //Long int mapped to long long
#define S_AR_LONG_LL_4      3               //Long int mapped to long long
#define S_AR_LONG_LL_5      4               //Long int mapped to long long
#define S_AR_LONG_LL_6      5               //Long int mapped to long long
#define S_AR_LONG_LL_7      6               //Long int mapped to long long
#define S_AR_LONG_LL_8      7               //Long int mapped to long long
#define S_SZ_MS5607_BUF     10              //Size of MS5607 SPI Rx & Tx buffers
#define S_SZ_LCD_BUF        12              //Size of LCD SPI Rx & Tx buffers
#define S_TM_DB_MIN         58              //Minimum time for valid key-press
#define S_TM_DB_ST          30              //Short key-press
#define S_TM_DB_LG          5               //Long key-press
#define S_TM_DB             60              //Debounce timer max key-press
#define S_MK_FMT_COM        0x01            //Mask for comma in number display
#define S_MK_FMT_DEC        0x02            //Mask for decimal in number display
#define S_MK_FMT_NON        0x00            //No comma / decimal in display
#define S_SZ_LCD_CHAR       8               //Number of characters LCD can display
#define S_TM_LCD_BKLT       10              //Number of seconds backlight on
#define S_TM_SAMPLE         4               //Sample interval (in s) when not sleeping but should be same as sleep
#define S_IN_OFF            450             //Default deep sleep timout
#define S_MK_SETUP_ALT      0x04            //Setup altitude bit
#define S_MK_SETUP_BAR      0x02            //Setup baro bit
#define S_MK_SETUP_TOF      0x01            //Setup Timeout OFf (deep sleep) bit
#define S_MK_SETUP_FIRST    S_MK_SETUP_ALT  //First setup item to display
#define S_MK_SETUP_LAST     S_MK_SETUP_TOF  //Last setup item to display
#define S_QY_SECINMIN       60              //Number of seconds in a minute
#define S_LM_TOF_UP         720             //Maximim time off value in minutes
#define S_LM_TOF_DN         0               //Minimum time off value in minutes
#define S_QY_INCR_ST        1               //Increment value in setup with single button press
#define S_QY_INCR_RP        10              //Increment value in setup with repeat button press
#define S_TM_INCR_RP        350             //# mS between repeat value increments in setup


//LCD control constants
#define S_EN_LCD_DATA       1               //Control line value for data
#define S_EN_LCD_INST       0               //Control line value for instructions
#define S_TM_LCD_EXEC       5               //Instruction exec time, mS
#define S_CD_LCD_CHOME      0x02            //Cursor return home
#define S_IN_LCD_FCTST1     0x31            //Function set, instruction table 1
#define S_IN_LCD_BIASET     0x14            //Bias set
#define S_IN_LCD_PWRCTL     0x55            //Power control
#define S_IN_LCD_FLWCTL     0x6D            //Follower control
#define S_IN_LCD_CONSET     0x70            //Contrast set
#define S_IN_LCD_FCTST0     0x30            //Function set, instruction table 0
#define S_IN_LCD_DISPLY     0x0C            //Display control
#define S_IN_LCD_CLRDSP     0x01            //Clear display
#define S_IN_LCD_ENTRYM     0x06            //Entry mode set

//MS5607 constants
#define S_AR_MS5607_CMD     0               //Position of baro command byte in Tx
#define S_SZ_MS5607_RST     1               //Size of buffers for reset command
#define S_SZ_MS5607_CAL     8               //Size of array for calibration constants
#define S_SZ_MS5607_CMD     2               //# bytes in command sent to MS5607
#define S_SZ_MS5607_CEF     3               //Size of buffers to retrieve coefficient
#define S_SZ_MS5607_CNV     1               //Size of buffers for conversion command
#define S_SZ_MS5607_ADC     4               //Size of buffers for ADC read command
#define S_AR_MS5607_CEF_L   2               //Position of low byte in coefficient response
#define S_AR_MS5607_CEF_H   1               //Position of high byte in coefficient response
#define S_AR_MS5607_CEF_1   3               //Position of low byte in temp/baro response
#define S_AR_MS5607_CEF_2   2               //Position of middle byte in temp/baro response
#define S_AR_MS5607_CEF_3   1               //Position of high byte in temp/baro response
#define S_AR_MS5607_C0      0               //Coefficient - OEM data
#define S_AR_MS5607_C1      1               //Compensation coefficient 1
#define S_AR_MS5607_C2      2               //Compensation coefficient 2
#define S_AR_MS5607_C3      3               //Compensation coefficient 3
#define S_AR_MS5607_C4      4               //Compensation coefficient 4
#define S_AR_MS5607_C5      5               //Compensation coefficient 5
#define S_AR_MS5607_C6      6               //Compensation coefficient 6
#define S_AR_MS5607_CRC     7               //CRC data
#define S_RT_MS5607_P       32768           //Pressure calculation ratio
#define S_RT_MS5607_C1      65536           //Coefficient 1 calculation ratio
#define S_RT_MS5607_C2      131072          //Coefficient 2 calculation ratio
#define S_RT_MS5607_C3dT    128             //Coefficient 3/dT calculation ratio
#define S_RT_MS5607_C4dT    64              //Coefficient 4/dT calculation ratio
#define S_RT_MS5607_C5      256             //Coefficient 5 calculation ratio
#define S_RT_MS5607_C6      8388608         //Coefficient 6 calculation ratio
#define S_RT_MS5607_SENS    2097152         //Sensitivity calculation ratio
#define S_RT_MS5607_dT      2147483648      //dT calculation ratio
#define S_RT_MS5607_OFF2    16              //Offset 2 calculation ratio
#define S_TM_MS5607_CMD     10              //Command completion time, mS, for MS5607
#define S_AD_MS5607_R       239             //I2C read address for MS5607
#define S_AD_MS5607_W       238             //I2C write address for MS5607
#define S_CD_MS5607_RST     30              //Command: reset
#define S_CD_MS5607_C0      160             //Command: read OEM data
#define S_CD_MS5607_C1      162             //Command: read coefficient 1
#define S_CD_MS5607_C2      164             //Command: read coefficient 2
#define S_CD_MS5607_C3      166             //Command: read coefficient 3
#define S_CD_MS5607_C4      168             //Command: read coefficient 4
#define S_CD_MS5607_C5      170             //Command: read coefficient 5
#define S_CD_MS5607_C6      172             //Command: read coefficient 6
#define S_CD_MS5607_CRC     174             //Command: read CRC
#define S_CD_MS5607_D2_256  80              //Command: temperature acquisition, OSR 256
#define S_CD_MS5607_D2_512  82              //Command: temperature acquisition, OSR 512
#define S_CD_MS5607_D2_1024 84              //Command: temperature acquisition, OSR 1024
#define S_CD_MS5607_D2_2048 86              //Command: temperature acquisition, OSR 2048
#define S_CD_MS5607_D2_4096 88              //Command: temperature acquisition, OSR 4096
#define S_CD_MS5607_D2      S_CD_MS5607_D2_512  //Temperature command used by firmware
#define S_CD_MS5607_D1_256  64              //Command: pressure acquisition, OSR 256
#define S_CD_MS5607_D1_512  66              //Command: pressure acquisition, OSR 512
#define S_CD_MS5607_D1_1024 68              //Command: pressure acquisition, OSR 1024
#define S_CD_MS5607_D1_2048 70              //Command: pressure acquisition, OSR 2048
#define S_CD_MS5607_D1_4096 72              //Command: pressure acquisition, OSR 4096
#define S_CD_MS5607_D1      S_CD_MS5607_D1_512  //Pressure command used by firmware
#define S_CD_MS5607_ADC     0               //Command: read ADC value from last acquisition
#define S_LM_MS5607_2ORD    2000            //Threshold for low temp 2nd order correction (20C)
#define S_LM_MS5607_VLTMP   1500            //Threshold for very low temp 2nd order correction (-15C)

//Altitude constants
#define S_QY_ALT_MBAR_INHG  33863           //mbar per inch Hg scaled (33.863)
#define S_QY_ALT_MBAR_METR  111             //mbar per meter (std. atmosphere) scaled (0.111)
#define S_QY_ALT_MBAR_STD   1013250         //Std. atmosphere MSL, mbar scaled (1013.25)
#define S_QY_ALT_HG_STD     29920           //Std. atmosphere MSL, Hg scaled (29.92)
#define S_LM_ALT_M_UP       9000            //Maximum altitude setting, meters
#define S_LM_ALT_M_DN       0               //Minimum altitude setting, meters
#define S_LM_ALT_F_UP       29530           //Maximum altitude setting, feet
#define S_LM_ALT_F_DN       0               //Minimum altitude setting, feet
#define S_LM_BAR_M_UP       110000          //Maximum baro setting, mbar
#define S_LM_BAR_M_DN       84659           //Minimum baro setting, mbar
#define S_LM_BAR_H_UP       3250            //Maximum baro setting, Hg
#define S_LM_BAR_H_DN       2500            //Minimum baro setting, Hg
#define S_LM_VS_S_MIN       1               //Minimum altitude change per sample, meters, to calculate vspeed
#define S_LM_AC_S_MIN       2               //Minimum altitude change per sample, meters, to accumulate
#define S_RT_VS_RATE        (S_QY_SECINMIN/S_TM_SAMPLE) //Vertical speed per sample multiplier to per minute
#define S_LM_AC_HYS         3               //Hysteresis to validate accumulator update

//Scaling constants
#define S_RT_DECIMAL_3      1000            //Three decimal resolution as int
#define S_RT_DECIMAL_2      100             //Two decimal resolution as int
#define S_RT_DECIMAL_1      10              //One decimal resolution as int



/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Analog channel mapping:  channel=port=pin.  The values assigned to these
 * constants should match those used by ADC.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define ANLCA0              0x00            //AN0=RA0=13
#define ANLCA1              0x04            //AN1=RA1=12
#define ANLCA2              0x08            //AN2=RA2=11
#define ANLCA4              0x10            //AN4=RA4=3
#define ANLCA5              0x14            //AN5=RA5=2
#define ANLCC0              0x40            //ANC0=RC0=10
#define ANLCC1              0x44            //ANC1=RC1=9
#define ANLCC2              0x48            //ANC2=RC2=8
#define ANLCC3              0x4C            //ANC3=RC3=7
#define ANLCC4              0x50            //ANC4=RC4=6
#define ANLCC5              0x54            //ANC5=RC5=5


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * PPS input pin definitions.  Map for MCU and use to assign peripheral input
 * pins.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define PPSRA0              0x00            //RA0
#define PPSRA1              0x01            //RA1
#define PPSRA2              0x02            //RA2
#define PPSRA3              0x03            //RA3
#define PPSRA4              0x04            //RA4
#define PPSRA5              0x05            //RA5
#define PPSRC0              0x10            //RC0
#define PPSRC1              0x11            //RC1
#define PPSRC2              0x12            //RC2
#define PPSRC3              0x13            //RC3
#define PPSRC4              0x14            //RC4
#define PPSRC5              0x15            //RC5


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                           PPS & direct pin mapping
 * 
 * For PPS output pin assignments both aliases for pin registers and constants 
 * mapping what peripheral connects to the pin.
 *      Pin register alias convention:  PPS_P_XXX_YY where
 *          XXX=peripheral name
 *          YY=channel or other detail; can be omitted
 *      Peripheral mapping convention:  PPS_M_XXX_YY same as alias
 * 
 * Input pins only require mapping constant.
 * 
 * For pins accessed directly or assigned in a peripheral's register (like ADC)
 * use the following convention:  PIN_XT_YYYYYY where
 *          X=(I)nput or (O)utput
 *          T=(A)nalog or (D)igital
 *          YYYYYY=user assigned mnemonic describing function
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//SPI outputs
#define PPS_P_SPI_CLK   RC0PPS                  //Pin 10: clock is RC0
#define PPS_P_SPI_SDO   RC2PPS                  //Pin 8: serial data out is RC2
#define PPS_M_SPI_CLK   0x18
#define PPS_M_SPI_SDO   0x19

//SPI inputs
#define PPS_P_SPI_SDI   PPSRC1                  //Pin 9: serial data in is RC1

//MS5607 baro sensor SPI Chip Select pin
#define PIN_OD_CS_BARO  RC3                     //Pin 7: SPI chip select for MS5607
#define S_MK_CS_BARO    0x08                    //RC3 bit position in PORTC reg

//Power pins
#ifdef HWR210120
#define PIN_OD_PW_LB    RA0                     //Pin 13: LCD & baro sensor power
#define PIN_OD_CHGP     RA4                     //Pin 3: Charge pump/LDO enable
#define PIN_OD_BL_LCD   RC5                     //Pin 5: LCD backlight power
#else
#define PIN_OD_CHGP     RA0                     //Pin 13: Charge pump/LDO enable
#define PIN_OD_PW_LB    RA1                     //Pin 12: LCD & baro sensor power
#define PIN_OD_BL_LCD   RA2                     //Pin 11: LCD backlight power
#endif

//LCD control pins
#ifdef HWR210120
#define PIN_OD_RS_LCD   RA2                     //Pin 11: 0=instruction, 1=data
#else
#define PIN_OD_RS_LCD   RC5                     //Pin 5: 0=instruction, 1=data
#endif
#define PIN_OD_CS_LCD   RC4                     //Pin 6: SPI chip select for LCD
#define S_MK_CS_LCD     0x10                    //RC4 bit position in PORTC reg

//User input - button control pins
#define PIN_ID_UP       RA5                     //Pin 2: display select, backlight, up
#define PIN_IOC_UP      IOCAF5                  //Interrupt on change for PIN_ID_UP
#ifdef HWR210120
#define PIN_ID_DOWN     RA3                     //Pin 4: Units select, setup, down
#define PIN_IOC_DOWN    IOCAF3                  //Interrupt on change for PIN_ID_DOWN
#else
#define PIN_ID_DOWN     RA4                     //Pin 3: Units select, setup, down
#define PIN_IOC_DOWN    IOCAF4                  //Interrupt on change for PIN_ID_DOWN
#endif


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Port/pin configuration: I/O, analog/digital, slew rate, etc.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//Port I/O: 1=input, 0=output
#ifdef HWR210120
#define IO_PORTA        0b00101000
#else
#define IO_PORTA        0b00111000
#endif
#define IO_PORTC        0b00000010
//Port Analog/Digital: 1=analog, 0=digital
#define AD_PORTA        0b00000000
#define AD_PORTC        0b00000000
//Port weak pull-up: 1=enabled, 0=disabled
#ifdef HWR210120
#define WP_PORTA        0b00000000
#else
#define WP_PORTA        0b00001000
#endif
#define WP_PORTC        0b00000000
//Open drain: 1=open drain, 0=push-pull
#define OD_PORTA        0b00000000
#define OD_PORTC        0b00000000
//Slew rate: 1=limited, 0=maximum
#define SR_PORTA        0b00000000
#define SR_PORTC        0b00000000
//Input level: 1=ST, 0=TLL
#define IL_PORTA        0b00000000
#define IL_PORTC        0b00000000
//Initial pin states
#ifdef HWR210120
#define S_IN_PORTA      0b00000100
#define S_IN_PORTC      0b00011000
#else
#define S_IN_PORTA      0b00000000
#define S_IN_PORTC      0b00111000
#endif
//IOC for port A - up/down buttons, +/- transitions
#ifdef HWR210120
#define IOC_PORTA_P     0b00101000
#define IOC_PORTA_N     0b00101000
#else
#define IOC_PORTA_P     0b00110000
#define IOC_PORTA_N     0b00110000
#endif


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * SYSTEM MACROS:
 * + LCDHOME commands the LCD controller to move the cursor to start of display.
 * + LCDINI initializes the LCD module
 * + BAROINI resets the MS5607 baro sensor
 * + CTRLOFF sets control pins low on LCD & baro sensor to prevent current sink
 *   during power-off sleep
 * + CTRLON sets control pins to normal operating state
 * + RESETAHYS clears the climb/descent accumulator hysteresis counters
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define LCDHOME()   PIN_OD_RS_LCD=S_EN_LCD_INST;lcd_txb[0]=S_CD_LCD_CHOME;\
    lcd_h.szb = 1;spi_m_TxData(&lcd_h);PIN_OD_RS_LCD = S_EN_LCD_DATA
#define LCDINI()    PIN_OD_RS_LCD=S_EN_LCD_INST;\
    for (lcd_h.szb=1, counter=0; (counter<9); ++counter)\
    {\
        lcd_h.txb=(lcd_inib+counter);\
        spi_m_TxData(&lcd_h);\
        __delay_ms(S_TM_LCD_EXEC);\
    }\
    lcd_h.txb=lcd_txb;\
    PIN_OD_RS_LCD=S_EN_LCD_DATA
#define BAROINI()   baro_txb[S_AR_MS5607_CMD]=S_CD_MS5607_RST;\
    baro_h.szb = S_SZ_MS5607_RST;\
    spi_m_TxData(&baro_h);
#define CTRLOFF()   PIN_OD_RS_LCD=FALSE;PIN_OD_CS_LCD=FALSE;PIN_OD_CS_BARO=FALSE
#define CTRLON()    PIN_OD_RS_LCD=TRUE;PIN_OD_CS_LCD=TRUE;PIN_OD_CS_BARO=TRUE
#define RESETAHYS() hys_climb=0;hys_descent=0


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * PERIPHERAL MODULE DISABLE
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_PMD_0       0x46            //FVR, NVM, CLKR off
#define CFG_PMD_1       0xBF            //TMR0-5, NCO off
#define CFG_PMD_2       0x44            //CMP1-2, ADC, DAC off
#define CFG_PMD_3       0xFF            //CCP1-4, PWM5-6, CWG1-2 off
#define CFG_PMD_4       0x24            //MSSP2, UART1 off
#define CFG_PMD_5       0x1F            //DSM, CLC1-4 off


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Timer6 configuration: provides interrupt timing for background caretaker 
 * that performs system monitor & control.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_TMR_6_CON   0x23            //Off, 1:64 prescale, 1:5 post scale
#define CFG_TMR_6_PR    124             //Period value to obtain 10mS period


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                          Print & Format Constants
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                          Object definitions
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * EEPROM memory definitions.  For non-volatile storage of configurable
 * parameters. Emulates program flash storage concept of a row (portability).
 * 
 * Word values must be stored in little endian (L|H) format.
 * 
 * Important:  flash architecture is PIC family dependent and the memory map /
 * constants must be reviewed when changing MCUs.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define FLASHROWSZ          32              //Size of flash row: PIC specific or
                                            //emulated for EEPROM
#define FLASH_SZ_CSUM   (FLASHROWSZ - 2)    //Store checksum in last word of row

//EEPROM starting offset: defines where in EEPROM row starts.
#define FLASH_ROW_START     0

//Checksum stored in little endian format in last word of row
#define FLASH_AR_CSUM_L (FLASHROWSZ - 2)
#define FLASH_AR_CSUM_H (FLASHROWSZ - 1)
#define FLASH_AR_CSUM   (FLASH_AR_CSUM_L / sizeof(uint16_t))

//Default data to initialize row with.  Positions 30 & 31 reserved for checksum.
#define S_DF_FLASH_0        0
#define S_DF_FLASH_1        0
#define S_DF_FLASH_2        0
#define S_DF_FLASH_3        0
#define S_DF_FLASH_4        0
#define S_DF_FLASH_5        0
#define S_DF_FLASH_6        0
#define S_DF_FLASH_7        0
#define S_DF_FLASH_8        0
#define S_DF_FLASH_9        0
#define S_DF_FLASH_10       0
#define S_DF_FLASH_11       0
#define S_DF_FLASH_12       0
#define S_DF_FLASH_13       0
#define S_DF_FLASH_14       0
#define S_DF_FLASH_15       0
#define S_DF_FLASH_16       0
#define S_DF_FLASH_17       0
#define S_DF_FLASH_18       0
#define S_DF_FLASH_19       0
#define S_DF_FLASH_20       0
#define S_DF_FLASH_21       0
#define S_DF_FLASH_22       0
#define S_DF_FLASH_23       0
#define S_DF_FLASH_24       0
#define S_DF_FLASH_25       0
#define S_DF_FLASH_26       0
#define S_DF_FLASH_27       0
#define S_DF_FLASH_28       0
#define S_DF_FLASH_29       0


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Function declarations.  See source file for explanation of each function.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
void main(void);
void fmtLCDdsp(unsigned char, char, char, char *, signed long);
unsigned char crc4(signed long long *);
void __interrupt() InterruptExec(void);
void Initialize(void);


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Preprocessor checks.  Maintain at end of main include file.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/



//End of file