/*

DESCRIPTION:    include file for spi.c.

KNOWN BUGS:     n/a.

COPYRIGHT:      (c) 2020, Brian Cornell, all rights reserved.

DEPENDENCIES:  

VERSION:        1.0

MODIFICATION HISTORY:

    9 Dec 20, BWC, first release

*/


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * MSSP register configurations
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_SSP1_STAT       0xC0            //Input sampled @ end, SPI mode 0
#define CFG_SSP1_CON_1      0x0A            //Disabled, SPI mode 0, clock=ADD
#define CFG_SSP1_CON_2      0x00            //Not used for SPI
#define CFG_SSP1_CON_3      0x00            //Not used for SPI master
#define CFG_SSP1_ADD        0x09            //400kHz


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * MODULE CONSTANTS
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define SPI_SET             1
#define SPI_CLR             0
#define S_MK_CS_ON          0xFF


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * MODULE error code object spi_errno values
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define SPI_ERR_NONE        0               //No error


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * MACROS:
 * + SPI_M_CONFIG - configure MSSP peripheral
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define SPI_M_CONFIG()  SSP1CON1bits.SSPEN = SPI_CLR; SSP1CON1 = CFG_SSP1_CON_1; \
    SSP1CON2 = CFG_SSP1_CON_2; SSP1CON3 = CFG_SSP1_CON_3; \
    SSP1ADD = CFG_SSP1_ADD; SSP1STAT = CFG_SSP1_STAT; SSP1CON1bits.SSPEN = SPI_SET
#define SPIENABLE()     SSP1CON1bits.SSPEN = SPI_SET
#define SPIDISABLE()    SSP1CON1bits.SSPEN = SPI_CLR


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Data object definitions
 * + spi_h - SPI handle
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
typedef struct {
    unsigned char           *rxb;           //Receive buffer
    unsigned char           *txb;           //Transmit buffer
    unsigned char           szb;            //# bytes to tx/rx (<= rxb/txb size)
    unsigned char           csp;            //Set bit for port pin to control
    volatile unsigned char  *port;          //Address of i/o PORT
} spi_h;


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Function declarations.  See source file for documentation.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
void spi_m_TxData(spi_h *);



//End of file